package be.iminds.ilabt.jfed.testing.tests.highlevel.config;

import com.fasterxml.jackson.annotation.*;

import javax.annotation.Nullable;

@JsonInclude(JsonInclude.Include.NON_DEFAULT)
@JsonIgnoreProperties(value={"@context"})
public class Cleanup {
    private final boolean enabled;
    private final boolean ignoreErrors;
    private final long maxWaitTimeMinutes;

    public Cleanup() {
        this.enabled = true;
        this.ignoreErrors = false;
        this.maxWaitTimeMinutes = 5;
    }

    @JsonCreator
    public Cleanup(@Nullable @JsonProperty("enabled") Boolean enabled,
                   @Nullable @JsonProperty("ignoreErrors") Boolean ignoreErrors,
                   @Nullable @JsonProperty("maxWaitTimeMinutes") Long maxWaitTimeMinutes) {
        this.enabled = enabled == null ? new Cleanup().isEnabled() : enabled;
        this.ignoreErrors = ignoreErrors == null ? new Cleanup().getIgnoreErrors() : ignoreErrors;
        this.maxWaitTimeMinutes = maxWaitTimeMinutes == null ? new Cleanup().getMaxWaitTimeMinutes() : maxWaitTimeMinutes;
    }

    @JsonIgnore
    public boolean isValid() {
        if (!enabled)
            return true;

        if (maxWaitTimeMinutes < 0)
            throw new IllegalArgumentException("Config Error: cleanup.maxWaitTimeMinutes < 0 makes no sense");

        return true;
    }

    @JsonProperty
    public boolean isEnabled() {
        return enabled;
    }

    @JsonProperty
    public boolean getIgnoreErrors() {
        return ignoreErrors;
    }

    @JsonProperty
    public long getMaxWaitTimeMinutes() {
        return maxWaitTimeMinutes;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof Cleanup)) return false;

        Cleanup cleanup = (Cleanup) o;

        if (enabled != cleanup.enabled) return false;
        if (ignoreErrors != cleanup.ignoreErrors) return false;
        return maxWaitTimeMinutes == cleanup.maxWaitTimeMinutes;
    }

    @Override
    public int hashCode() {
        int result = (enabled ? 1 : 0);
        result = 31 * result + (ignoreErrors ? 1 : 0);
        result = 31 * result + (int) (maxWaitTimeMinutes ^ (maxWaitTimeMinutes >>> 32));
        return result;
    }
}
